From: Jens Lehmann <Jens.Lehmann@web.de>
To: Ari Pollak <ari@debian.org>, git@vger.kernel.org
Cc: Junio C Hamano <gitster@pobox.com>
Subject: Re: Bug? diff.submodule=log adds text to commit -v message
Date: Mon, 11 Nov 2013 22:29:25 +0100 [thread overview]
Message-ID: <52814C35.6040205@web.de> (raw)
In-Reply-To: <loom.20131111T214646-550@post.gmane.org>
Am 11.11.2013 21:48, schrieb Ari Pollak:
> Jens Lehmann writes:
>> And after adding a modified file the log message also shows the diff of
>> that file (and without leading "# "s too), so I doubt that diffs aren't
>> normally included in the commit message with -v. What am I missing?
>
> Ah, it is true that -v normally does not prefix the diffs with #, but there
> must be some filter in place after I save & quit my editor when a normal file
> diff is present, since that does not get included in the final commit
> message. But the submodule log does get included, which does not seem
> intentional.
Ok, now this makes sense. "git commit" strips off the diff added by
-v by skipping everything starting with "\ndiff --git ". But that
logic fails when the "diff.submodule = log" setting adds a shortlog
instead of a regular diff, as that starts with "\nSubmodule ".
The diff below fixes the problem you describe for me. (But I do not
consider it a worthwhile fix in its current form because a line
starting with "Submodule " might appear in a perfectly normal commit
message, while "diff --git " most probably won't).
And while testing this issue I noticed another problem: When using
"git commit -a" not only the staged commits of a submodule get
committed, but also the unstaged commits. Will look into that too.
-------------------------8<---------------------
diff --git a/builtin/commit.c b/builtin/commit.c
index 6ab4605..ff6e171 100644
--- a/builtin/commit.c
+++ b/builtin/commit.c
@@ -1600,11 +1600,14 @@ int cmd_commit(int argc, const char **argv, const char *
die(_("could not read commit message: %s"), strerror(saved_errno
}
/* Truncate the message just before the diff, if any. */
if (verbose) {
p = strstr(sb.buf, "\ndiff --git ");
if (p != NULL)
strbuf_setlen(&sb, p - sb.buf + 1);
+ p = strstr(sb.buf, "\nSubmodule ");
+ if (p != NULL)
+ strbuf_setlen(&sb, p - sb.buf + 1);
}
if (cleanup_mode != CLEANUP_NONE)
next prev parent reply other threads:[~2013-11-11 21:29 UTC|newest]
Thread overview: 23+ messages / expand[flat|nested] mbox.gz Atom feed top
2013-11-10 21:49 Bug? diff.submodule=log adds text to commit -v message Ari Pollak
2013-11-11 20:41 ` Jens Lehmann
2013-11-11 20:48 ` Ari Pollak
2013-11-11 21:29 ` Jens Lehmann [this message]
2013-11-11 21:34 ` Jens Lehmann
2013-11-11 23:24 ` Jeff King
2013-11-12 7:46 ` Johannes Sixt
2013-11-12 22:17 ` Jens Lehmann
2013-11-12 22:20 ` Junio C Hamano
2013-11-13 18:37 ` Jens Lehmann
2013-11-13 20:04 ` Junio C Hamano
2013-11-16 22:52 ` [RFC PATCH] commit -v: strip diffs and submodule shortlogs from the commit message Jens Lehmann
2013-11-17 0:22 ` Eric Sunshine
2013-11-17 8:53 ` Jeff King
2013-11-17 9:09 ` Jeff King
2013-11-17 12:20 ` Jens Lehmann
2013-11-18 16:01 ` Junio C Hamano
2013-11-19 18:47 ` [PATCH v2 ] " Jens Lehmann
2013-11-19 19:07 ` Junio C Hamano
2013-11-19 19:31 ` Junio C Hamano
2013-11-19 19:42 ` Junio C Hamano
2013-11-19 20:34 ` Junio C Hamano
2013-11-19 21:01 ` Jens Lehmann
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=52814C35.6040205@web.de \
--to=jens.lehmann@web.de \
--cc=ari@debian.org \
--cc=git@vger.kernel.org \
--cc=gitster@pobox.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -1600,11 +1600,14 @@ int cmd_commit(int argc, const char **argv, const char *
die(_("could not read commit message: %s"), strerror(saved_errno
}
- /* Truncate the message just before the diff, if any. */
+ /* Truncate the message just before the diff or submodule shortlog */
if (verbose) {
p = strstr(sb.buf, "\ndiff --git ");
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.